TVector4

Struct TVector4 

pub struct TVector4<T> {
    pub x: T,
    pub y: T,
    pub z: T,
    pub w: T,
}

Fields

x: Ty: Tz: Tw: T

Implementations

Source

impl<T> TVector4<T>
where T: Zero<T> + Copy,

pub fn empty() -> Self

Creates TVector4<type> whose x, y, z and w equal to zero

use iomath::vectors::Vector4;
 
let vector = Vector4::empty();
assert_eq!(vector, Vector4 { x: 0.0, y: 0.0, z: 0.0, w: 0.0 });
pub fn new(x: T, y: T, z: T, w: T) -> Self

Creates TVector4<type> with x, y, z and w

use iomath::vectors::Vector4;
 
let vector = Vector4::new(3.7, -1.3, 0.5, 6.4);
assert_eq!(vector, Vector4 { x: 3.7, y: -1.3, z: 0.5, w: 6.4 });
pub fn from_scalar(scalar: T) -> Self

Creates TVector4<type> whose x, y, z, and w equal to scalar

use iomath::vectors::Vector4;
 
let vector = Vector4::from_scalar(9.0);
assert_eq!(vector, Vector4::new(9.0, 9.0, 9.0, 9.0));
pub fn from_two_values_vector( first_val: T, second_val: T, vector: TVector2<T>, ) -> Self

Creates TVector4<type> whose x equals to first value, y to second value, z and w to TVector2<type>’s x and y

use iomath::vectors::{ Vector4, Vector2 };
 
let vector = Vector4::from_two_values_vector(4.0, 5.0, Vector2::new(6.0, 7.0));
assert_eq!(vector, Vector4::new(4.0, 5.0, 6.0, 7.0));
pub fn from_value_vector_value( first_val: T, vector: TVector2<T>, second_val: T, ) -> Self

Creates TVector4<type> whose x equals to first value,y and z to TVector2<type>’s x and y, w to second value

use iomath::vectors::{ Vector4, Vector2 };
 
let vector = Vector4::from_value_vector_value(4.0, Vector2::new(6.0, 7.0), 5.0);
assert_eq!(vector, Vector4::new(4.0, 6.0, 7.0, 5.0));
pub fn from_vector_two_values( vector: TVector2<T>, first_val: T, second_val: T, ) -> Self

Creates TVector4<type> whose x and y equal to TVector2<type>’s x and y, z to first value, w to second value

use iomath::vectors::{ Vector4, Vector2 };
 
let vector = Vector4::from_vector_two_values(Vector2::new(6.0, 7.0), 4.0, 5.0);
assert_eq!(vector, Vector4::new(6.0, 7.0, 4.0, 5.0));
pub fn from_two_vectors( first_vector: TVector2<T>, second_vector: TVector2<T>, ) -> Self

Creates TVector4<type> whose x and y equal to first TVector2<type>’s x and y, z and w to second TVector2<type>’s x and y

use iomath::vectors::{ Vector4, Vector2 };
 
let vector = Vector4::from_two_vectors(Vector2::new(4.0, 7.0), Vector2::new(5.0, 6.0));
assert_eq!(vector, Vector4::new(4.0, 7.0, 5.0, 6.0));
pub fn from_value_vector(value: T, vector: TVector3<T>) -> Self

Creates TVector4<type> whose x equals to value, y, z and w equal to TVector3<type>’s x, y and z

use iomath::vectors::{ Vector4, Vector3 };
 
let vector = Vector4::from_value_vector(1.7, Vector3::new(1.4, 5.5, 2.3));
assert_eq!(vector, Vector4::new(1.7, 1.4, 5.5, 2.3));
pub fn from_vector_value(vector: TVector3<T>, value: T) -> Self

Creates TVector4<type> whose x, y and z equal to TVector3<type>’s x, y and z, w equals to value

use iomath::vectors::{ Vector4, Vector3 };
 
let vector = Vector4::from_vector_value(Vector3::new(1.4, 5.5, 2.3), 1.7);
assert_eq!(vector, Vector4::new(1.4, 5.5, 2.3, 1.7));